package example_complete_application_order_menu;
	
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javafx.application.Application;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.geometry.Insets;
import javafx.geometry.Pos;
import javafx.stage.Stage;
import javafx.scene.Scene;
import javafx.scene.chart.BarChart;
import javafx.scene.chart.CategoryAxis;
import javafx.scene.chart.Chart;
import javafx.scene.chart.LineChart;
import javafx.scene.chart.NumberAxis;
import javafx.scene.chart.ScatterChart;
import javafx.scene.chart.XYChart;
import javafx.scene.control.Button;
import javafx.scene.control.CheckBox;
import javafx.scene.control.Label;
import javafx.scene.control.RadioButton;
import javafx.scene.control.Slider;
import javafx.scene.control.Tab;
import javafx.scene.control.TabPane;
import javafx.scene.control.TextArea;
import javafx.scene.control.ToggleGroup;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Pane;
import javafx.scene.layout.VBox;

public class Main2 extends Application {
	protected CheckBox ckbBurger, ckbDrink, ckbFries;
	protected Button btnFood, btnClear;
	protected TextArea txaMessage;
	protected ToggleGroup tGrpDiningChoice;
	protected RadioButton rbDineIn, rbTakeOut, rbDelivery;
	protected Slider sldSatisfaction;
	protected RadioButton rbBar, rbLine, rbScatter;
	protected ToggleGroup tGrpGraphChoice;
	protected GridPane grdChartPane;
	protected Chart prevChart;
	
	@Override
	public void start(Stage primaryStage) {
		try {
			Scene scene = new Scene(buildGui(),500,550);
			scene.getStylesheets().add(getClass().getResource("application.css").toExternalForm());
			primaryStage.setTitle("Food Order System");			
			primaryStage.setScene(scene);
			primaryStage.show();
		} catch(Exception e) {
			e.printStackTrace();
		}
	}
	
	private Pane buildGui() {
		// Build menu tab
		Tab tabFood = new Tab();
		tabFood.setText("Menu");
		tabFood.setContent(buildMenuTab());
		tabFood.setClosable(false);
	    // Build chart tab
		Tab tabGraph = new Tab();
		tabGraph.setText("Bar Chart");
		tabGraph.setContent(buildBarChartTab());
		tabGraph.setClosable(false);
		// Build tab pane
		TabPane tabPane = new TabPane();
		tabPane.getTabs().addAll(tabFood,tabGraph);
		// Build root pane
		BorderPane root = new BorderPane();
		root.setCenter(tabPane);
		return root;
	}
/*
 *  Menu Tab	
 */
	private Pane buildMenuTab() {
		GridPane grdPane = new GridPane();
		
		grdPane.add(buildFoodSelection(), 0, 0);
		grdPane.add(buildDiningChoice(), 0, 1);
		grdPane.add(buildSatisfactionSlider(), 0, 2);
		grdPane.add(buildButtons(), 0, 3);

		txaMessage = new TextArea();
		grdPane.add(txaMessage, 0, 4);
		return grdPane;
	}
	
	private Pane buildFoodSelection() {
		ckbBurger = new CheckBox("Burger");
		ckbDrink = new CheckBox("Drink");
		ckbFries = new CheckBox("Fries");
	
		HBox hbxFood = new HBox();
		hbxFood.getChildren().addAll(ckbBurger,ckbDrink,ckbFries);
	
		return hbxFood;
	}

	private Pane buildDiningChoice() {
		tGrpDiningChoice = new ToggleGroup();
		rbDineIn = new RadioButton("Dine In");
		rbDineIn.setSelected(true);
		rbDineIn.setToggleGroup(tGrpDiningChoice);
		rbTakeOut = new RadioButton("Take Out");
		rbTakeOut.setToggleGroup(tGrpDiningChoice);
		rbDelivery = new RadioButton("Delivery");
		rbDelivery.setToggleGroup(tGrpDiningChoice);

		HBox hbxDiningChoice = new HBox();
		hbxDiningChoice.getChildren().addAll(rbDineIn,rbTakeOut,rbDelivery);

		return hbxDiningChoice;
	}

	private Pane buildButtons() {
		btnFood = new Button("Process");
        btnFood.setOnAction(new FoodButtonEventHandler());
		btnClear = new Button("Clear");
        btnClear.setOnAction(new ClearButtonEventHandler());

		HBox hbxButtons = new HBox();
		hbxButtons.getChildren().addAll(btnFood,btnClear);

		return hbxButtons;
	}
	
	private Pane buildSatisfactionSlider() {
		sldSatisfaction = new Slider();
		sldSatisfaction.setMin(-5.0);
		sldSatisfaction.setMax(5.0);
		sldSatisfaction.setValue(0);
		sldSatisfaction.setShowTickLabels(true);
		sldSatisfaction.setShowTickMarks(true);
		sldSatisfaction.setMajorTickUnit(1);
		sldSatisfaction.setMinorTickCount(1);
		sldSatisfaction.setSnapToTicks(true);
	//		sldSatisfaction.setBlockIncrement(2);
		Label lbl = new Label("Satisfaction: ");
		VBox vBox = new VBox();
		vBox.getChildren().addAll(lbl,sldSatisfaction);
		
		return vBox;
	}
/*
 * Build Chart Tab
 */
	private Pane buildBarChartTab() {
		grdChartPane = new GridPane();
	
		grdChartPane.add(buildChartChoice(), 0, 0);
		prevChart = buildChart("Bar");
		grdChartPane.add(prevChart, 0, 1);
		return grdChartPane;
	}

	private Pane buildChartChoice() {
		tGrpGraphChoice = new ToggleGroup();
		rbBar = new RadioButton("Bar");
		rbBar.setSelected(true);
		rbBar.setToggleGroup(tGrpGraphChoice);
		rbLine = new RadioButton("Line");
		rbLine.setToggleGroup(tGrpGraphChoice);
		rbScatter = new RadioButton("Scatter");
		rbScatter.setToggleGroup(tGrpGraphChoice);
	
		Button btnDisplay = new Button("Display");
		btnDisplay.setOnAction(new DisplayChartEventHandler());
	
		HBox vbxChartChoice = new HBox();
		vbxChartChoice.setAlignment(Pos.CENTER);
		vbxChartChoice.getChildren().addAll(rbBar, rbLine, rbScatter, btnDisplay);
		
		return vbxChartChoice;
	}

	private class DisplayChartEventHandler implements EventHandler<ActionEvent> {
		@Override
		public void handle(ActionEvent event) {
			RadioButton rad = (RadioButton)tGrpGraphChoice.getSelectedToggle();
			String choice = rad.getText();
			grdChartPane.getChildren().remove(prevChart);
			grdChartPane.add(buildChart(choice),0,1);
		}
	}
	
	private Chart buildChart(String type) {
		// Create axis
	    CategoryAxis xAxis = new CategoryAxis();
	    NumberAxis yAxis = new NumberAxis();
        xAxis.setLabel("Item");       
        yAxis.setLabel("$");
		// Create chart
	    XYChart<String,Number> c = new BarChart<String,Number>(xAxis,yAxis);
		if(type.equals("Bar")) {
			c = new BarChart<String,Number>(xAxis,yAxis);			
		}
		else if(type.equals("Line")) {
			c = new LineChart<String,Number>(xAxis,yAxis);			
		}
		else if(type.equals("Scatter")) {
			c = new ScatterChart<String,Number>(xAxis,yAxis);			
		}
        c.setTitle("Sales Summary");
		
		// Initialize data
	    List<String> months = new ArrayList<>(Arrays.asList("June", "July", "August"));
	    List<String> foodNames = new ArrayList<>(Arrays.asList("Burgers", "Drinks", "Fries"));
	    List<Double> burgerSales = new ArrayList<>(Arrays.asList(14502.33, 16003.40, 13200.70));
	    List<Double> drinkSales = new ArrayList<>(Arrays.asList(12332.93, 13592.84, 14992.39));
	    List<Double> frySales = new ArrayList<>(Arrays.asList(9820.42, 13592.84, 5523.65 ));

	    // Build chart
        for(int i=0; i<foodNames.size(); i++) {
            XYChart.Series<String,Number> series = new XYChart.Series<>();
            series.setName(months.get(i));       
            int j=0;
            series.getData().add(new XYChart.Data<String,Number>(foodNames.get(j++), burgerSales.get(i)));
            series.getData().add(new XYChart.Data<String,Number>(foodNames.get(j++), drinkSales.get(i)));
            series.getData().add(new XYChart.Data<String,Number>(foodNames.get(j),   frySales.get(i)));
            c.getData().add(series);
        }
        return c;
	}
	

    private class FoodButtonEventHandler implements EventHandler<ActionEvent> {
		@Override
		public void handle(ActionEvent event) {
			double cost = 0.0;
			String order = "Order:\n";
			if(ckbBurger.isSelected()) {
				cost += 5.99;
				order += "Burger";
			}
			if(ckbDrink.isSelected()) {
				cost += 1.99;
				order += ", Drink";
			}

			if(ckbFries.isSelected()) {
				cost += 1.49;
				order += ", Fries";
			}
			
			RadioButton rad = (RadioButton)tGrpDiningChoice.getSelectedToggle();
			
			if(rad.getText().equals("Delivery")) {
				cost += 5.00;
			}
			
			String totCost = String.format("\nTotal: $%,.2f\n", cost);
			order += totCost;
			order += "*** " + rad.getText() + " ***\n";
			order += "Satisfaction: " + sldSatisfaction.getValue();

            txaMessage.setText(order);
		}

    }

    private class ClearButtonEventHandler implements EventHandler<ActionEvent> {
		@Override
		public void handle(ActionEvent event) {
			ckbBurger.setSelected(false);
			ckbDrink.setSelected(false);
			ckbFries.setSelected(false);
			rbDineIn.setSelected(true);
			sldSatisfaction.setValue(0.0);
			txaMessage.clear();
		}
    }

	public static void main(String[] args) {
		launch(args);
	}
}
