package example_shape_generator;

// Illustrates: RadioButtons, ToggleGroup, Nesting Panes
//
import java.io.File;
import java.util.ArrayList;

import javafx.application.Application;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.geometry.Insets;
import javafx.geometry.Pos;
import javafx.stage.FileChooser;
import javafx.stage.Stage;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.ComboBox;
import javafx.scene.control.Label;
import javafx.scene.control.RadioButton;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextField;
import javafx.scene.control.ToggleGroup;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Pane;
import javafx.scene.layout.VBox;

public class ShapeGenerator extends Application {

	protected TextField txfValue1, txfValue2, txfValue3;
	protected TextArea txaMessage;
	protected ArrayList<GeometricObject> shapes = new ArrayList<>();
	protected ComboBox<String> cmbShape;
	protected Label lbl1, lbl2, lbl3;
	protected Button btnCreateShape, btnShowAll;
	protected ToggleGroup tGrpShapeChoice = new ToggleGroup();
	private Button btnReadShape;

	@Override
	public void start(Stage primaryStage) {
		Pane grdRootPane = buildGui(primaryStage);
		Scene scene = new Scene(grdRootPane,450, 400);
		scene.getStylesheets().add(getClass().getResource("application.css").toExternalForm());
		primaryStage.setScene(scene);
		primaryStage.setTitle("Shape Generator");
		primaryStage.show();
	}
	
	private Pane buildGui(Stage stage) {
	    VBox root = new VBox();
	    root.getChildren().addAll(buildTopRow(), buildMiddleRow(), buildBottomRow());
	    return root;
	}
	
	private Pane buildTopRow() {
		HBox topRow = new HBox();
		topRow.setAlignment(Pos.CENTER);  // Should be done with CSS
		topRow.getChildren().addAll(buildSelectShapePane(), buildEnterShapeDataPane());
		return topRow;
	}
	
	private Pane buildSelectShapePane() {
		VBox vBoxShape = new VBox();
		Label lblSelectShape = new Label("Select Shape");
		vBoxShape.getChildren().add(lblSelectShape);
	
	    ShapeChoiceEventHandler cmbShapeEventHandler = new ShapeChoiceEventHandler();
	
		RadioButton rbTriangle = new RadioButton("Triangle");
		rbTriangle.setToggleGroup(tGrpShapeChoice);
		rbTriangle.setSelected(true);
		rbTriangle.setOnAction(cmbShapeEventHandler);
		vBoxShape.getChildren().add(rbTriangle);
	
		RadioButton rbRectangle = new RadioButton("Rectangle");
		rbRectangle.setToggleGroup(tGrpShapeChoice);
		rbRectangle.setOnAction(cmbShapeEventHandler);
		vBoxShape.getChildren().add(rbRectangle);
	
		RadioButton rbCircle = new RadioButton("Circle");
		rbCircle.setToggleGroup(tGrpShapeChoice);
		rbCircle.setOnAction(cmbShapeEventHandler);
		vBoxShape.getChildren().add(rbCircle);
	
		return vBoxShape;
	}
	
	private Pane buildEnterShapeDataPane() {
		GridPane gridShapeLengths = new GridPane();
		
		lbl1 = new Label("Side 1:");
		gridShapeLengths.add(lbl1, 0, 1);
		txfValue1 = new TextField();
		gridShapeLengths.add(txfValue1, 1, 1);
		lbl2 = new Label("Side 2:");
		gridShapeLengths.add(lbl2, 0, 2);
		txfValue2 = new TextField();
		gridShapeLengths.add(txfValue2, 1, 2);
		lbl3 = new Label("Side 3:");
		gridShapeLengths.add(lbl3, 0, 3);
		txfValue3 = new TextField();
		gridShapeLengths.add(txfValue3, 1, 3);
	
		return gridShapeLengths;
	}
	
	private Pane buildMiddleRow() {
		HBox hBoxButtons = new HBox();
		hBoxButtons.setAlignment(Pos.CENTER); // Should be done with CSS
	
		// Create and add buttons
		btnCreateShape = new Button("Create Triangle");
		hBoxButtons.getChildren().add(btnCreateShape);
		btnShowAll = new Button("Show All");
		hBoxButtons.getChildren().add(btnShowAll);
	
	    // Create button event handlers
	    CreateShapeEventHandler btnEventHandler = new CreateShapeEventHandler();
	    btnCreateShape.setOnAction(btnEventHandler );
	
	    ShowAllEventHandler btnShowAllEventHandler = new ShowAllEventHandler();
	    btnShowAll.setOnAction(btnShowAllEventHandler );
	
	    return hBoxButtons;
	}
	
	private Pane buildBottomRow() {
		HBox hBoxMessage = new HBox();
		hBoxMessage.setAlignment(Pos.CENTER);
	    txaMessage = new TextArea();
	    txaMessage.setEditable(false);
	    txaMessage.setPrefColumnCount(22);
	    txaMessage.setPrefRowCount(6);
	    HBox.setMargin(txaMessage, new Insets(30,0,0,0));
	    hBoxMessage.getChildren().add(txaMessage);
	    return hBoxMessage;
	}

    private class CreateShapeEventHandler implements EventHandler<ActionEvent> {

		@Override
		public void handle(ActionEvent event) {

			RadioButton rad = (RadioButton)tGrpShapeChoice.getSelectedToggle();

         	String strShape = rad.getText();

         	GeometricObject shape = null;

         	switch( strShape ) {
         	case "Triangle":
         		System.out.println("Creating a Triangle");
               	// Get triangle side lengths
            	double side1 = Double.parseDouble( txfValue1.getText() );
            	double side2 = Double.parseDouble( txfValue2.getText() );
            	double side3 = Double.parseDouble( txfValue3.getText() );
            	// Create triangle object
            	shape = new Triangle(side1, side2, side3);
         		break;
         	case "Rectangle":

         		System.out.println("Creating a Rectangle");
               	// Get rectangle width and height
            	double width = Double.parseDouble( txfValue1.getText() );
            	double height = Double.parseDouble( txfValue2.getText() );
            	// Create triangle object
            	shape = new Rectangle(width, height);
         		break;

         	case "Circle":
         		System.out.println("Creating a Circle");
               	// Get rectangle width and height
            	double radius = Double.parseDouble( txfValue1.getText() );
            	// Create triangle object
            	shape = new Circle(radius);
         		break;
         	}

        	// Add to collection
        	shapes.add(shape);

        	// Build message to display
        	StringBuilder message = new StringBuilder();
        	message.append("Shape:\n");
        	message.append( shape.toString() + "\n" );

        	String temp = String.format("   Area      = %4.1f\n", shape.getArea());
        	message.append(temp);
        	temp = String.format("   Perimeter = %4.1f\n", shape.getPerimeter());
        	message.append(temp);

        	// Put message in display area
            txaMessage.setText(message.toString());

            // Erase fields
            txfValue1.setText(null);
            txfValue2.setText(null);
            txfValue3.setText(null);

		}

    }

    private class ShowAllEventHandler implements EventHandler<ActionEvent> {

 		@Override
 		public void handle(ActionEvent event) {

         	StringBuilder message = new StringBuilder();
         	message.append("All Shapes:\n");

 			for( GeometricObject shape : shapes ) {
 				message.append(shape + "\n");
 			}

             txaMessage.setText(message.toString());

             // Erase fields
             txfValue1.setText(null);
             txfValue2.setText(null);
             txfValue3.setText(null);
 		}
     }

    private class ShapeChoiceEventHandler implements EventHandler<ActionEvent> {

 		@Override
 		public void handle(ActionEvent event) {
 			RadioButton rb = (RadioButton)event.getSource();

         	String shape = rb.getText();

         	switch( shape ) {
         	case "Triangle":
         		System.out.println("Triangle");
         		showTriangleEntry();
         		break;
         	case "Rectangle":

         		System.out.println("Rectangle");
         		showRectangleEntry();
         		break;

         	case "Circle":
         		System.out.println("Circle");
         		showCircleEntry();
         		break;
         	}
 		}
     }

     private void showTriangleEntry() {
  		lbl1.setVisible(true);
  		lbl1.setText("Side 1:");
  		txfValue1.setVisible(true);

  		lbl2.setVisible(true);
  		lbl2.setText("Side 2:");
  		txfValue2.setVisible(true);

  		lbl3.setVisible(true);
  		lbl2.setText("Side 3:");
  		txfValue3.setVisible(true);

  		btnCreateShape.setText("Create Triangle");
     }

    private void showRectangleEntry() {
 		lbl1.setVisible(true);
 		lbl1.setText("Width:");
 		txfValue1.setVisible(true);

 		lbl2.setVisible(true);
 		lbl2.setText("Height:");
 		txfValue2.setVisible(true);

 		lbl3.setVisible(false);
 		txfValue3.setVisible(false);

 		btnCreateShape.setText("Create Rectangle");
    }

    private void showCircleEntry() {
 		lbl1.setVisible(true);
 		lbl1.setText("Radius:");
 		txfValue1.setVisible(true);

 		lbl2.setVisible(false);
 		txfValue2.setVisible(false);

 		lbl3.setVisible(false);
 		txfValue3.setVisible(false);

  		btnCreateShape.setText("Create Circle");
    }

	public static void main(String[] args) {
		launch(args);
	}
}
