package examples_controls;

import javafx.application.Application;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.stage.Stage;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.control.Slider;
import javafx.scene.control.TextArea;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.Pane;
import javafx.scene.layout.VBox;

public class SliderExample extends Application {
	
	protected Slider sldSatisfaction;
	protected TextArea txaMessage;
	
	@Override
	public void start(Stage primaryStage) {
		GridPane grdRootPane = buildGuiPane();
		Scene scene = new Scene(grdRootPane,450,250);
		scene.getStylesheets().add(getClass().getResource("application.css").toExternalForm());
		primaryStage.setScene(scene);
		primaryStage.setTitle("Slider Example");
		primaryStage.show();
	}
	
	private GridPane buildGuiPane() {
		GridPane grid = new GridPane();
		grid.add(buildSatisfactionSlider(), 0, 0);
	
		Button btnProcess = new Button("Process");
		btnProcess.setOnAction(new ProcessEventHandler());
		grid.add(btnProcess, 0, 1);
	
	    txaMessage = new TextArea();
	    txaMessage.setEditable(false);
	    txaMessage.setPrefColumnCount(10);
	    txaMessage.setPrefRowCount(4);
	    txaMessage.setMaxWidth(250);
	    grid.add(txaMessage, 0, 2);
		
	    return grid;				
	}
	
	private Pane buildSatisfactionSlider() {
		sldSatisfaction = new Slider();
		sldSatisfaction.setMinWidth(400);
		sldSatisfaction.setMin(-5.0);
		sldSatisfaction.setMax(5.0);
		sldSatisfaction.setValue(0);
		sldSatisfaction.setShowTickLabels(true);
		sldSatisfaction.setShowTickMarks(true);
		sldSatisfaction.setMajorTickUnit(1);
		sldSatisfaction.setMinorTickCount(1);
		sldSatisfaction.setSnapToTicks(true);
//			sldSatisfaction.setBlockIncrement(2);
		Label lbl = new Label("Satisfaction: ");
		VBox vBox = new VBox();
		vBox.getChildren().addAll(lbl,sldSatisfaction);
		
		return vBox;
	}
	
	private class ProcessEventHandler implements EventHandler<ActionEvent> {
		@Override
		public void handle(ActionEvent event) {
			
			double sat = sldSatisfaction.getValue();
			String satMessage = "Your satisfaction is: " + sldSatisfaction.getValue();
			if(sat<-2.5)
				satMessage = "Sorry things were really bad";
			else if(sat<0.0)
				satMessage = "Sorry things weren't better";
			else if(sat<2.5)
				satMessage = "Glad things were OK";
			else
				satMessage = "Glad things were great";
	
			String message = "Your satisfaction is: " + sat + "\n" + satMessage;
	
	        txaMessage.setText(message);
		}
	}

	public static void main(String[] args) {
		launch(args);
	}
}
