package examples_panes;

import javafx.application.*;
import javafx.event.*;
import javafx.scene.*;
import javafx.scene.control.*;
import javafx.scene.layout.*;
import javafx.stage.*;

// Illustrates: BorderPane, TextField, Button, TextArea
//
// Uses inner class for event handler.
//
// Note: Controls that need to be accessed in
// the event handler must be declared as
// instance variables.
public class BorderPaneExample extends Application {

	TextArea txaMessage;
	TextField txfName;

	@Override
	public void start(Stage primaryStage) {

		// Build Gui
		BorderPane brdRootPane = new BorderPane();
		
		Label lblTop = new Label("Top");
		Label lblRight = new Label("Right");
		Label lblBottom = new Label("Bottom");
		Label lblLeft = new Label("Left");
		Label lblCenter = new Label("Center");
	
		lblTop.setMaxWidth(Double.MAX_VALUE);
		lblRight.setMaxWidth(Double.MAX_VALUE);
		lblBottom.setMaxWidth(Double.MAX_VALUE);
		lblLeft.setMaxWidth(Double.MAX_VALUE);
		lblCenter.setMaxWidth(Double.MAX_VALUE);
		
		setLabelStyle(lblTop);
		setLabelStyle(lblRight);
		setLabelStyle(lblBottom);
		setLabelStyle(lblLeft);
		setLabelStyle(lblCenter);
		
		brdRootPane.setTop(lblTop);
		brdRootPane.setRight(lblRight);
		brdRootPane.setBottom(lblBottom);
		brdRootPane.setLeft(lblLeft);
		brdRootPane.setCenter(lblCenter);

		// Display Gui
		Scene scene = new Scene(brdRootPane,125,125);
		primaryStage.setScene(scene);
		primaryStage.setTitle("Example - BorderPane");
		primaryStage.show();
	}

	private void setLabelStyle(Label lbl) {
		lbl.setStyle("-fx-padding: 10;" +
	            "-fx-border-style: solid inside;" +
	            "-fx-border-width: 2;" +
	            "-fx-border-insets: 5;" +
	            "-fx-border-radius: 5;" +
	            "-fx-border-color: red;");
	}
	public static void main(String[] args) {
		launch(args);
	}

	// Inner class, event handler
    private class HelloWorldButtonEventHandler implements EventHandler<ActionEvent> {
		@Override
        public void handle(ActionEvent e) {
        	String name = txfName.getText();
            txaMessage.setText(name + ", Hello World!");
        }
    }

}
